@@ -4,6 +4,7 @@ use crate::app::launcher::App;
 use crate::app::mode::Mode;
 use crate::app::prompt::OutputType;
 use crate::app::tab::Tab;
+use crate::app::util;
 use crate::gpg::key::KeyType;
 use crate::term::tui::Tui;
 use crate::widget::row::ScrollDirection;
@@ -220,6 +221,7 @@ fn handle_key_event(key_event: KeyEvent, app: &mut App) -> Command {
 								_ => KeyType::Public,
 							},
 							vec![selected_key.get_id()],
+							false,
 						),
 						None => Command::ShowOutput(
 							OutputType::Failure,
@@ -375,9 +377,18 @@ fn handle_command_execution<B: Backend>(
 					Ok(Mode::Visual) => tui.disable_mouse_capture()?,
 					_ => {}
 				}
+			} else if option == "prompt" && value == ":import " {
+				tui.toggle_pause()?;
+				toggle_pause = true;
+				match util::run_xplr() {
+					Ok(files) => {
+						command = Command::ImportKeys(files, false);
+					}
+					Err(e) => eprintln!("{:?}", e),
+				}
 			}
 		}
-		Command::ExportKeys(_, _)
+		Command::ExportKeys(_, _, _)
 		| Command::DeleteKey(_, _)
 		| Command::GenerateKey
 		| Command::RefreshKeys
@@ -454,7 +465,11 @@ mod tests {
 				vec![KeyEvent::new(Key::Char('u'), Modifiers::NONE)],
 			),
 			(
-				Command::ExportKeys(KeyType::Public, vec![key_id.to_string()]),
+				Command::ExportKeys(
+					KeyType::Public,
+					vec![key_id.to_string()],
+					false,
+				),
 				vec![KeyEvent::new(Key::Char('x'), Modifiers::NONE)],
 			),
 			(
